/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.uberfire.backend.vfs;

import org.uberfire.commons.lifecycle.Disposable;
import org.uberfire.mvp.Command;
import org.uberfire.mvp.ParameterizedCommand;
import org.uberfire.rpc.SessionInfo;

public interface ObservablePath extends Path,
                                        Disposable {

    void onRename(final Command command);

    void onDelete(final Command command);

    void onUpdate(final Command command);

    void onCopy(final Command command);

    void onConcurrentRename(final ParameterizedCommand<OnConcurrentRenameEvent> command);

    void onConcurrentDelete(final ParameterizedCommand<OnConcurrentDelete> command);

    void onConcurrentUpdate(final ParameterizedCommand<OnConcurrentUpdateEvent> command);

    void onConcurrentCopy(final ParameterizedCommand<OnConcurrentCopyEvent> command);

    ObservablePath wrap(final Path path);

    Path getOriginal();

    public interface OnConcurrentUpdateEvent extends SessionInfo {

        Path getPath();
    }

    public interface OnConcurrentDelete extends SessionInfo {

        Path getPath();
    }

    public interface OnConcurrentRenameEvent extends SessionInfo {

        Path getSource();

        Path getTarget();
    }

    public interface OnConcurrentCopyEvent extends SessionInfo {

        Path getSource();

        Path getTarget();
    }
}
